==> prestashop_edition_basic_version_8.0.4.zip: modules/ps_metrics/src/Middleware/LogMiddleware.php <==
<?php

/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace PrestaShop\Module\Ps_metrics\Middleware;

use PrestaShop\Module\Ps_metrics\Adapter\LoggerAdapter;

class LogMiddleware extends Middleware
{
    /**
     * @var LoggerAdapter
     */
    private $loggerAdapter;

    public function __construct(LoggerAdapter $loggerAdapter)
    {
        $this->loggerAdapter = $loggerAdapter;
    }

    /**
     * @param array $response
     *
     * @return array
     */
    public function execute($response): array
    {
        if (!empty($response['error'])) {
            $this->loggerAdapter->error($response['error'], ['error_code' => $response['code']]);
        }
        // Do nothing for the moment
        return parent::execute($response);
    }
}

==> prestashop_edition_basic_version_8.2.0.zip: modules/ps_metrics/src/Middleware/LogMiddleware.php <==
<?php

/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
namespace PrestaShop\Module\Ps_metrics\Middleware;

use PrestaShop\Module\Ps_metrics\Adapter\LoggerAdapter;
class LogMiddleware extends \PrestaShop\Module\Ps_metrics\Middleware\Middleware
{
    /**
     * @var LoggerAdapter
     */
    private $loggerAdapter;
    public function __construct(LoggerAdapter $loggerAdapter)
    {
        $this->loggerAdapter = $loggerAdapter;
    }
    /**
     * @param array $response
     *
     * @return array
     */
    public function execute($response)
    {
        if (!empty($response['error'])) {
            $this->loggerAdapter->error($response['error'], ['error_code' => $response['code']]);
        }
        // Do nothing for the moment
        return parent::execute($response);
    }
}
